Learn R Programming

wishmom (version 1.1.0)

denpoly: Coefficients of the Denominator Polynomial for \(\tilde{H}_k\) and \(\tilde{C}_k\)

Description

This function computes the coefficients of the denominator polynomial for the elements of \(\tilde{H}_k\) and \(\tilde{C}_k\). The function returns a vector containing the coefficients in descending powers of \(\tilde{n}\), with the last element being the coefficient of \(\tilde{n}\).

Usage

denpoly(k, alpha = 2)

Value

A vector containing the coefficients of the denominator polynomial in descending powers of \(\tilde{n}\) for the elements of \(\tilde{H}_k\) and \(\mathcal{C}_k\).

Arguments

k

The order of the polynomial (a positive integer)

alpha

The type of Wishart distribution \((\alpha=2/\beta)\):

  • 1/2: Quaternion Wishart

  • 1: Complex Wishart

  • 2: Real Wishart (default)

Examples

Run this code
# Example 1: Compute the denominator polynomial for k = 3, alpha = 2
# Output corresponds to the polynomial n1^5-3n1^4-8n1^3+12n1^2+16n1,
# where n1 is \eqn{\tilde{n}}
denpoly(3)

# Example 2: Compute the denominator polynomial for k = 2, alpha = 1
# Output corresponds to the polynomial n1^3-n1, where n1 is \eqn{\tilde{n}}
denpoly(2, alpha = 1)

Run the code above in your browser using DataLab