Learn R Programming

wishmom (version 1.1.0)

iwish_ps: Inverse of a Coefficient Matrix \(\tilde{\mathcal{H}}_k\)

Description

This function computes the inverse of a coefficient matrix \(\tilde{\mathcal{H}}_k\) that allows us to compute the expected value of a power-sum symmetric function of \(W^{-1}\), where \(W \sim W_m^{\beta}(n,\Sigma)\).

Usage

iwish_ps(k, alpha = 2)

Value

Inverse of a coefficient matrix \(\tilde{\mathcal{H}}_k\) that allows us to compute the expected value of a power-sum symmetric function of \(W^{-1}\), where \(W \sim W_m^{\beta}(n,\Sigma)\). The matrix is represented as a 3-dimensional array where each slice along the third dimension represents a coefficient matrix of the polynomial in descending powers of \(\tilde{n}\).

Arguments

k

The order of the \(\tilde{\mathcal{H}}_k\) matrix (a positive integer)

alpha

The type of Wishart distribution (\(\alpha = 2/\beta\)):

  • 1/2: Quaternion Wishart

  • 1: Complex Wishart

  • 2: Real Wishart (default)

Examples

Run this code
# Example 1:
iwish_ps(3) # For real Wishart distribution with k = 3

# Example 2:
iwish_ps(4, 1) # For complex Wishart distribution with k = 4

# Example 3:
iwish_ps(2, 1/2) # For quaternion Wishart distribution with k = 2

Run the code above in your browser using DataLab