Learn R Programming

wishmom (version 1.1.0)

iwish_psr: Coefficient Matrix \(\tilde{\mathcal{H}}_k\)

Description

This function computes the coefficient matrix \(\tilde{\mathcal{H}}_k\) for \(W \sim W_m^{\beta}(n, \Sigma)\).

Usage

iwish_psr(k, alpha = 2)

Value

A list with two elements:

  • c: A 3-dimensional array containing the coefficient matrices of the numerator of \(\tilde{\mathcal{H}}_k\) in descending powers of \(n1\), where \(n1 = n - m + 1 - \alpha\)

  • den: A vector containing the coefficients of the denominator of \(\tilde{\mathcal{H}}_k\), in descending powers of \(n1\)

Arguments

k

The order of the \(\tilde{\mathcal{H}}_k\) matrix (a positive integer)

alpha

The type of Wishart distribution (\(\alpha = 2/\beta\)):

  • 1/2: Quaternion Wishart

  • 1: Complex Wishart

  • 2: Real Wishart (default)

Examples

Run this code
# Example 1:
iwish_psr(2) # For real Wishart distribution with k = 2

# Example 2:
iwish_psr(4, 1) # For complex Wishart distribution with k = 4

# Example 3:
iwish_psr(2, 1/2) # For quaterion Wishart distribution with k = 2

Run the code above in your browser using DataLab