Learn R Programming

wishmom (version 1.1.0)

qk_coeff: Coefficient Matrix \(\mathcal{C}_k\)

Description

This function computes the coefficient matrix \(\mathcal{C}_k\), which is a matrix of constants that allows us to obtain \(E[p_{\lambda}(W)W^r]\), where \(r+|\lambda|=k\) and \(W \sim W_m^{\beta}(n, \Sigma)\).

Usage

qk_coeff(k, alpha = 2)

Value

\(\mathcal{C}_k\), a matrix that allows us to obtain \(E[p_{\lambda}(W)W^r]\), where \(r+|\lambda|=k\) and \(W \sim W_m^{\beta}(n, \Sigma)\). The matrix is represented as a 3-dimensional array where each slice along the third dimension represents a coefficient matrix of the polynomial in descending powers of \(n\).

Arguments

k

The order of the \(\mathcal{C}_k\) matrix

alpha

The type of Wishart distribution (\(\alpha=2/\beta\)):

  • 1/2: Quaternion Wishart

  • 1: Complex Wishart

  • 2: Real Wishart (default)

Examples

Run this code
# Example 1:
qk_coeff(2) # For real Wishart distribution with k = 2

# Example 2:
qk_coeff(3, 1) # For complex Wishart distribution with k = 3

# Example 3:
qk_coeff(2, 1/2) # For quaternion Wishart distribution with k = 2

Run the code above in your browser using DataLab