Learn R Programming

wishmom (version 1.1.0)

qkn_coeff: Inverse of a Coefficient Matrix \(\tilde{\mathcal{C}}_k\)

Description

This function computes the inverse of the coefficient matrix \(\tilde{\mathcal{C}}_k\)

Usage

qkn_coeff(k, alpha = 2)

Value

Inverse of a coefficient matrix \(\tilde{\mathcal{C}}_k\) that allows us to obtain \(E[p_{\lambda}(W^{-1})W^{-r}]\), where \(r+|\lambda|=k\)

and \(W ~ W_m^{\beta}(n,\Sigma)\). The matrix is represented as a 3-dimensional array where each slice along the third dimension represents a coefficient matrix of the polynomial in descending powers of \(\tilde{n}\).

Arguments

k

The order of the \(\tilde{\mathcal{C}}_k\) matrix

alpha

The type of beta-Wishart distribution (\(\alpha=2/\beta\)):

  • 1/2: Quaternion Wishart

  • 1: Complex Wishart

  • 2: Real Wishart (default)

Examples

Run this code
# Example 1:
qkn_coeff(2) # For real Wishart distribution with k = 2
# Example 2:
qkn_coeff(3, 1) # For complex Wishart distribution with k = 3

# Example 3:
qkn_coeff(2, 1/2) # For quaternion Wishart distribution with k = 2

Run the code above in your browser using DataLab