Learn R Programming

wishmom (version 1.1.0)

wish_ps: Coefficient Matrix \(\mathcal{H}_k\)

Description

This function computes the coefficient matrix \(\mathcal{H}_k\) that allows us to compute the expected value of a power-sum symmetric function of \(W\), where \(W \sim W_m^{\beta}(n,\Sigma)\).

Usage

wish_ps(k, alpha = 2)

Value

A coefficient matrix \(\mathcal{H}_k\) that allows us to compute the expected value of a power-sum symmetric function of \(W\), where \(W \sim W_m^{\beta}(n,\Sigma)\). The matrix is represented as a 3-dimensional array where each slice along the third dimension represents a coefficient matrix of the polynomial in descending powers of \(n\).

Arguments

k

The order of the \(\mathcal{H}_k\) matrix

alpha

The type of Wishart distribution (\(\alpha = 2/\beta\)):

  • 1/2: Quaternion Wishart

  • 1: Complex Wishart

  • 2: Real Wishart (default)

Examples

Run this code
# Example 1:
wish_ps(3) # For real Wishart distribution with k = 3

# Example 2:
wish_ps(4, 1) # For complex Wishart distribution with k = 4

# Example 3:
wish_ps(2, 1/2) # For quaternion Wishart distribution with k = 2

Run the code above in your browser using DataLab