Learn R Programming

wishmom (version 1.1.0)

wishmom_sym: Symbolic Expectation of a Matrix-valued Function of a beta-Wishart Distribution

Description

When iw = 0, the function returns an analytical expression of \(E[\prod_{j=1}^r \mbox{tr}(W^j)^{f_j}]\), where \(W \sim W_m^{\beta}(n, S)\). When iw != 0, the function returns an analytical expression of \(E[\prod_{j=1}^r \mbox{tr}(W^j)^{f_j}W^{iw}]\). For a given f, iw, and alpha, this function provides the aforementioned expectations in terms of the variables \(n\) and \(\Sigma\).

Usage

wishmom_sym(f, iw = 0, alpha = 2, latex = FALSE)

Value

When iw = 0, it returns an analytical expression of \(E[\prod_{j=1}^r \mbox{tr}(W^j)^{f_j}]\). When iw != 0, it returns an analytical expression of \(E[\prod_{j=1}^r \mbox{tr}(W^j)^{f_j}W^{iw}]\). If latex = FALSE, the output is a data frame that stores the coefficients for calculating the result. If latex = TRUE, the output is a LaTeX formatted string of the result in terms of \(n\) and \(\Sigma\).

Arguments

f

A vector of nonnegative integers \(f_j\) that represents the power of \(\mbox{tr}(W^{-j})\), where \(j=1, \ldots, r\)

iw

The power of the beta-Wishart matrix \(W^{-1}\) (0 by default)

alpha

The type of Wishart distribution \((\alpha=2/\beta)\):

  • 1/2: Quaternion Wishart

  • 1: Complex Wishart

  • 2: Real Wishart (default)

latex

A Boolean indicating whether the output will be a LaTeX string or a dataframe (FALSE by default)

Examples

Run this code
# Example 1: For E[tr(W)^4] with W ~ W_m^1(n,Sigma), represented as a dataframe:
wishmom_sym(4) # iw = 0, for real Wishart distribution

# Example 2: For E[tr(W)*tr(W^2)W] with W ~ W_m^1(n,S), represented as a dataframe:
wishmom_sym(c(1, 1), 1) # iw = 1, for real Wishart distribution

# Example 3: For E[tr(W)^4] with W ~ W_m^2(n,S), represented as a LaTeX string:
# Using writeLines() to format
writeLines(wishmom_sym(4, 0, 1, latex=TRUE)) # iw = 0, for complex Wishart distribution

# Example 4: For E[tr(W)*tr(W^2)W] with W ~ W_m^2(n,S), represented as a LaTeX string:
# Using writeLines() to format
writeLines(wishmom_sym(c(1, 1), 1, 1, latex=TRUE)) # iw = 1, for real Wishart distribution

Run the code above in your browser using DataLab